#include "history.h"
#include <stddef.h>

#define UNDO_MAX 160000

stack* init_stack() {
    stack* s = malloc(sizeof(*s));
    s->top = NULL;
    s->size = 0;
}

node* init_node(uchar* data) {
    node* n = malloc(sizeof(*n));
    n->d = data;
    n->prev = NULL;
    return n;
}

void push(stack* s, node* x, uint y) {
    if(s->size > UNDO_MAX) return; //this is problematic as we don't store the latest change..
    if(s->top != NULL) x->prev = s->top;
    s->top = x;
    s->top->line = y;
    s->size++;
}

void push_c(stack* s, uchar c, uint y) {
    if(s->size == 0 || c == 32 || y > s->top->line) {
        uchar* temp = malloc(2 * sizeof(uchar));
        temp[0] = c; temp[1] = '\0';
        push(s, init_node(temp), y);
    } else {
        size_t len = strlen(s->top->d);
        uchar* str2 = malloc(len + 2);
        strcpy(str2, s->top->d);
        str2[len] = c;
        str2[len + 1] = '\0';
        s->top->d = str2;
        return;
    }

}

//modify current data until we hit space. once we hit space create a new history line

uchar* pop(stack* s) {
    if(s->top == NULL) return; //empty
    uchar* t = s->top->d;
    s->top = s->top->prev;
    s->size--;
    return t;
}

void display_undo(stack* s) {
    while(s->top != NULL) {
        printf("(%s, %i)->", s->top->d, s->top->line);
        pop(s);
    }
    printf("\n");
}

//for the case of undo having too many items.. 
//we need some way to possilby remove the first 500-1000 items we would need to free this chunk of memory and size -= 500;
//the question is what is the fastest way to do this and the best way to free this memory