#ifndef _MAIN
#define _MAIN

//SDL
#include <SDL2/SDL.h>
#include <SDL2/SDL_ttf.h>
#include <SDL2/SDL_opengl.h>

//KiWi
#include "KW_gui.h"
#include "KW_frame.h"
#include "KW_label.h"
#include "KW_widget_internal.h"
#include "KW_button.h"
#include "KW_renderdriver_sdl2.h"

//standard
#include <assert.h>
#include <stdarg.h>
#include <stdio.h>
#include <math.h>

//extras
#include "common.h"
#include "vec.h"
#include "history.h"
#include "syntax.h"

typedef struct {	//should store the syntax highlight offsets here instead of rebuilding the q every frame.
	uint size;
	uint f_char;
	uint s_a;
	PQ* syn;
	char* chars;
} Line;

typedef struct {
	uint   lines;
	Line*  buffer;
	char*  f_name;
	char*  f_type;
	char*  full;
  char*  path;
	uint   s_a;
	int    c_syntax;
	uVec2i l_pos;
	uVec2i l_off;
	uint   dirty;  
} Page;

//editor has an 2d array of tiles, these are our open
//[ only issue, no way to on type (h-split or v-split) unless magic?
//  TILE 1,
//  TILE 2
//]
//
//|~~~~~|~~~~~|
//|     |     |
//|_____|_____|
//if I hit split horizontal then we  another array which can be slected and cut the max_x in half for the first
//we could then render multiple "windows"

#define MAX_PAGES_PER_TILE 16
typedef struct {                  //in the future, it would be nice to have these be tree nodes
  Page pages[MAX_PAGES_PER_TILE]; //array of pages
  uVec2i t_size;                  //TILE SIZE (x , y)
  uint p_pos;                     //current position in pages array
  uint p_total;                   //current total pages in pages array
                                  //would be nice to store an individual status bar here depended on the t_size
} TILE;

#define ASCII_DISPLAY_LOW 32
#define ASCII_DISPLAY_HIGH 255

typedef struct {
	SDL_Texture* charMap;
	SDL_Rect glyph_table[ASCII_DISPLAY_HIGH - ASCII_DISPLAY_LOW + 1];
} Font;

typedef struct {
  TILE* tiles;
	/* stack* history; */
	uVec2i buffer_cursor;
	uVec2i offset;
	u8 quit: 1;
	uint visibleW, visibleH; //The number of visible chars both on the x and y axis
	uint screenW, screenH;   //True width and height of our window
	float font_scale;
  uint current_tile;
  uint t_total;
	Vec2i p_view;
	Vec2i mark; //ctrl space to set mark, if mark set ctrl space to set back to -1
	Font font;
  //char* copy; wouldn't be able to do cross window copy & paste need seperates for x11 & windows
  
} Editor;

typedef struct {
	KW_RenderDriver* driver;
	KW_Surface* set;
	KW_GUI* gui;
  KW_Font* font;

	KW_Widget* header;
	KW_Widget* footer;
	KW_Rect footer_geo;
	KW_Rect header_geo;
} GUI; //temporary structure..

typedef struct {
    SDL_KeyCode key;
    void (*run)();
    uint type;
	uint id;
} Command;

#endif
